    		Py Originals

    			./Py_Originals/gpl-3.0-standalone.html.HTML

    		Front Originals

    			./Front_Originals.HTML

    		Front Modules

    			./Front_Modules_Entire_Rules.txt
    			./Front_Modules_Legend_Rules.txt

    		Python Modules

    			./Py_Entire.json
    			./Py_Legend.txt

    			"ventures", "somatic", "Emergency", "biotech", "body_scan",
    			"botanist", plus "law_dictionary" licenses or rules can be found
    			at those directories.